<?php

/**

 * Simple Machines Forum (SMF)

 *

 * @package SMF

 * @author Simple Machines

 * @copyright 2011 Simple Machines

 * @license http://www.simplemachines.org/about/smf/license.php BSD

 *

 * @version 2.0.14

 */



/*	This template is, perhaps, the most important template in the theme. It

	contains the main template layer that displays the header and footer of

	the forum, namely with main_above and main_below. It also contains the

	menu sub template, which appropriately displays the menu; the init sub

	template, which is there to set the theme up; (init can be missing.) and

	the linktree sub template, which sorts out the link tree.



	The init sub template should load any data and set any hardcoded options.



	The main_above sub template is what is shown above the main content, and

	should contain anything that should be shown up there.



	The main_below sub template, conversely, is shown after the main content.

	It should probably contain the copyright statement and some other things.



	The linktree sub template should display the link tree, using the data

	in the $context['linktree'] variable.



	The menu sub template should display all the relevant buttons the user

	wants and or needs.



	For more information on the templating system, please see the site at:

	http://www.simplemachines.org/

*/



// Initialize the template... mainly little settings.

function template_init()

{

	global $context, $settings, $options, $txt;



	/* Use images from default theme when using templates from the default theme?

		if this is 'always', images from the default theme will be used.

		if this is 'defaults', images from the default theme will only be used with default templates.

		if this is 'never' or isn't set at all, images from the default theme will not be used. */

	$settings['use_default_images'] = 'never';



	/* What document type definition is being used? (for font size and other issues.)

		'xhtml' for an XHTML 1.0 document type definition.

		'html' for an HTML 4.01 document type definition. */

	$settings['doctype'] = 'xhtml';



	/* The version this template/theme is for.

		This should probably be the version of SMF it was created for. */

	$settings['theme_version'] = '2.0';



	/* Set a setting that tells the theme that it can render the tabs. */

	$settings['use_tabs'] = true;



	/* Use plain buttons - as opposed to text buttons? */

	$settings['use_buttons'] = true;



	/* Show sticky and lock status separate from topic icons? */

	$settings['separate_sticky_lock'] = true;



	/* Does this theme use the strict doctype? */

	$settings['strict_doctype'] = false;



	/* Does this theme use post previews on the message index? */

	$settings['message_index_preview'] = false;



	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */

	$settings['require_theme_strings'] = true;

}



// The main sub template above the content.

function template_html_above()

{

	global $context, $settings, $options, $scripturl, $txt, $modSettings;



	// Show right to left and the character set for ease of translating.

	echo '<!DOCTYPE html>

<html lang="', $txt['lang_dictionary'],'" ', $context['right_to_left'] ? ' dir="rtl"' : '', '>

<head>

	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />';



	// The ?fin20 part of this link is just here to make sure browsers don't cache it wrongly.

	echo '

	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/bootstrap.css" />

	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/all.css?fin20" />

	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/index', $context['theme_variant'], '.css?fin20" />';



	// Some browsers need an extra stylesheet due to bugs/compatibility issues.

	foreach (array('ie7', 'ie6', 'webkit') as $cssfix)

		if ($context['browser']['is_' . $cssfix])

			echo '

	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/', $cssfix, '.css" />';



	// RTL languages require an additional stylesheet.

	if ($context['right_to_left'])

		echo '

	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/rtl.css" />';



	// Here comes the JavaScript bits!

	echo '

	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/popper.js"></script>

	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/jquery.min.js?fin20"></script>

	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/bootstrap.min.js?fin20"></script>

	<script type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?fin20"></script>

	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/theme.js?fin20"></script>

	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/custom.js?fin20"></script>

	<script type="text/javascript"><!-- // --><![CDATA[

		var smf_theme_url = "', $settings['theme_url'], '";

		var smf_default_theme_url = "', $settings['default_theme_url'], '";

		var smf_images_url = "', $settings['images_url'], '";

		var smf_scripturl = "', $scripturl, '";

		var txtnew = "', $txt['new'], '";

		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';

		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '

		var fPmPopup = function ()

		{

			if (confirm("' . $txt['show_personal_messages'] . '"))

				window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");

		}

		addLoadEvent(fPmPopup);' : '', '

		var ajax_notification_text = "', $txt['ajax_in_progress'], '";

		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";

	// ]]></script>';



	echo '  

	<meta name="viewport" content="width=device-width, initial-scale=1">

	<meta name="description" content="', $context['page_title_html_safe'], '" />', !empty($context['meta_keywords']) ? '

	<meta name="keywords" content="' . $context['meta_keywords'] . '" />' : '', '

	<title>', $context['page_title_html_safe'], '</title>';



        	echo '

	<style type="text/css">

	@media (min-width: 979px) 

	{

		.container {

			max-width: ' . $settings['forum_width'] . ';

		}

	}

	</style>';

	// Please don't index these Mr Robot.

	if (!empty($context['robot_no_index']))

		echo '

	<meta name="robots" content="noindex" />';



	// Present a canonical url for search engines to prevent duplicate content in their indices.

	if (!empty($context['canonical_url']))

		echo '

	<link rel="canonical" href="', $context['canonical_url'], '" />';



	// Show all the relative links, such as help, search, contents, and the like.

	echo '

	<link rel="help" href="', $scripturl, '?action=help" />

	<link rel="search" href="', $scripturl, '?action=search" />

	<link rel="contents" href="', $scripturl, '" />';



	// If RSS feeds are enabled, advertise the presence of one.

	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))

		echo '

	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?type=rss;action=.xml" />';



	// If we're viewing a topic, these should be the previous and next topics, respectively.

	if (!empty($context['current_topic']))

		echo '

	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />

	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';



	// If we're in a board, or a topic for that matter, the index will be the board's index.

	if (!empty($context['current_board']))

		echo '

	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';



	// Output any remaining HTML headers. (from mods, maybe?)

	echo $context['html_headers'];



	echo '

</head>

<body class="nav-md top-bar-menu">';

}



function template_body_above()

{

	global $context, $settings, $options, $scripturl, $txt, $modSettings;



	echo '

	<div id="global-loader"></div>

<div class="page"> 

 <div class="page-main">

 <header class="p-header" id="header" style="background-image: url('.$settings['theme_url'].'/images/theme/header_background.jpg);"></header>';

		 echo '

	<div class="header"> 

	<div class="container"> 

	<div class="d-flex">

    <h1 class="forumtitle">

				<a class="header-brand" href="', $scripturl, '">', empty($context['header_logo_url_html_safe']) ? $context['forum_name'] : '<img src="' . $context['header_logo_url_html_safe'] . '" alt="' . $context['forum_name'] . '" />', '</a>

			</h1>	

	<div class="d-flex order-lg-2 ml-auto header-right-icons header-search-icon">

	 <div class="p-2 hidden">

<form class="input-icon " action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">

<div class="input-icon-addon"> <i class="fa fa-search"></i> </div>

					<input type="text" name="search" class="form-control header-search" value="', $txt['forum_search'], '" onfocus="this.value = \'\';" onblur="if(this.value==\'\') this.value=\'', $txt['forum_search'], '\';" />';



				// Search within current topic?

				if (!empty($context['current_topic']))

				echo '

					<input type="hidden" name="topic" value="', $context['current_topic'], '" />';



				// If we're on a certain board, limit it to this board ;).

				elseif (!empty($context['current_board']))

				echo '

					<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';



			echo '

				</form> 

 </div>

 <div class="user visitor dropdown text-center selector">';

	if ($context['user']['is_logged'])

	{

	if ($context['allow_pm'])

		echo '

		<a class="p-navgroup-link" href="', $scripturl, '?action=pm" data-toggle="tooltip" data-placement="bottom" title="', $txt['pm'], '"><i class="fa fa-envelope"></i><span class="badge badge-danger badge-pill noti-icon-badge">', $context['user']['messages'], '</span></a>';

        echo '

		<a  href="', $scripturl, '?action=profile" class="p-navgroup-link dropdown-toggle" data-toggle="dropdown">';

		if (!empty($context['user']['avatar']))

			echo '<img class="av rounded-circle" src="', $context['user']['avatar']['href'], '" alt="*"/>';

		else

			echo '<img class="av rounded-circle"  src="'.$settings['images_url'].'/noavatar.png" alt="*"/>';

		echo '

			

			<span class="name_admin hidden">', $context['user']['name'], ($context['user']['unread_messages'] == 0) ? '' : ' <span class="label label-primary visible-xs-inline">' . $context['user']['unread_messages'] . '</span>', '

			</span></a>';

					

					echo '

 <div class="dropdown-menu dropdown-menu-right">

					<a class="dropdown-item" href="', $scripturl, '?action=profile"><span class="fa fa-user"></span> ', $txt['summary'], '</a>

					<a class="dropdown-item" href="', $scripturl, '?action=profile;area=forumprofile"><span class="fa fa-wrench"></span> ', $txt['forumprofile'], '</a>

					<a class="dropdown-item" href="', $scripturl, '?action=profile;area=account"><span class="fa fa-cog"></span> ', $txt['account'], '</a>

					<a class="dropdown-item" href="', $scripturl, '?action=unread"><span class="fa fa-list"></span> ', $txt['unread_topics_visit'], '</a>

					<a class="dropdown-item" href="', $scripturl, '?action=unreadreplies"><span class="fa fa-comment"></span> ', $txt['unread_replies'], '</a>

					<div class="dropdown-divider"></div>';



		echo '

		<a class="dropdown-item" href="', $scripturl, '?action=logout;' . $context['session_var'] . '=' . $context['session_id']. '"><span class="fa fa-sign-out"></span> ', $txt['logout'], '</a></div>';

	}

	elseif (!empty($context['show_login_bar']))

	{

		echo '

		<a class="gor" data-toggle="modal" data-target="#giris"><i class="fa fa-lock" aria-hidden="true"></i><span class="hidden">',$txt['login'],'</span></a>

		<a class="register" href="' . $scripturl . '?action=register"><i class="fa fa-user-plus" aria-hidden="true"></i><span class="hidden">',$txt['register'],'</span></a>

		<div id="giris" class="modal fade " role="dialog">

		  <div class="modal-dialog modal-sm">

			<div class="modal-content">

			  <div class="modal-header">

				<button type="button" class="close" data-dismiss="modal">&times;</button>

				<h6 class="modal-title">',$txt['hello_guest'] . $txt['guest_title'],'</h6>

				<img class="avatar img-circle" src="'.$settings['images_url'].'/noavatar.png" alt="*" style="height: 96px;width: 96px"/>

			  </div>

			  <div class="modal-body">

				<script type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>

				<form class="form-horizontal" id="guest_form" action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" ', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>

					<input type="text" name="user"  class="form-control" placeholder="',$txt['username'],'"/>

					<input type="password" name="passwrd"  class="form-control" placeholder="',$txt['password'],'"/>

					<select name="cookielength" class="form-control">

						<option value="60">', $txt['one_hour'], '</option>

						<option value="1440">', $txt['one_day'], '</option>

						<option value="10080">', $txt['one_week'], '</option>

						<option value="43200">', $txt['one_month'], '</option>

						<option value="-1" selected="selected">', $txt['forever'], '</option>

					</select>

					<p class="text-center">', $txt['quick_login_dec'], '</p>

					<div class="form-group text-center"><input type="submit" class="btn btn-success" value="', $txt['login'], '"  /></div>';

		if (!empty($modSettings['enableOpenID']))

			echo '

					<br /><input type="text" name="openid_identifier" id="openid_url" size="25" class="input_text openid_login" />';

		echo '

					<input type="hidden" name="hash_passwrd" value="" /><input type="hidden" name="', $context['session_var'], '" value="', $context['session_id'], '" />

				</form> </div>

				</div>

			</div></div>';

	}

	echo '

 </div> 



               </div>

			   <a href="#" class="header-toggler d-lg-none ml-lg-0" data-toggle="collapse" data-target="#headerMenuCollapse"> <span class="header-toggler-icon"></span> </a>

            </div>

			</div>

            </div>';



	// i_menu.

	echo '

			<div class="admin-navbar" id="headerMenuCollapse">

			<div class="container">';



	// Show the menu here, according to the menu sub template.

	template_menu();



	echo '

		</div>

            </div>';



	// The main content should go here.

	echo '

	<div>

	<div class="container">';



	// Custom banners and shoutboxes should be placed here, before the linktree.



	// Show the navigation tree.

	theme_linktree();

}



function template_body_below()

{

	global $context, $settings, $options, $scripturl, $txt, $modSettings;



	echo '

		</div>

	</div></div>';



	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!

	echo '

	<div class="xenMakeFooter">';

	

	if(!empty($settings['footer_bits_content']) || !empty($settings['footer_blinks_state'])) {

    echo'<div class="container', (empty($settings['footer_bits_content'])||empty($settings['footer_blinks_state'])) ? 'single' : '', '">

        <ul class="footerColumnContainer">            

				<li class="footerColumn footer_col1">';

		if(!empty($settings['footer_bits_content']))

		echo'			

			<div class="block">

				<div class="block-container">

				<h3 class="block-minorHeader"><i class="fa fa-question-circle"></i>', empty($settings['footer_bits_title']) ? $context['forum_name'] : $settings['footer_bits_title'], '</h3>

					<div class="divider fw"></div>

					<div class="footer-content">', $settings['footer_bits_content'], '</div>

		          </div>

			     </div>						

                </li>           

				<li class="footerColumn footer_col2">			

				<div class="block" data-widget-id="0" data-widget-key="" data-widget-definition="forum_statistics">

	<div class="block-container">

		<h3 class="block-minorHeader"><i class="fas fa-chart-bar"></i>  ', $txt['forum_stats'], '</h3>

<div class="divider fw"></div>

		<div class="block-body block-row">

			<dl class="pairs pairs--justified">

				<dt>', $txt['posts_made'], ' ', $txt['in'], ' ', $txt['total'], '</dt>

				<dd>', $context['common_stats']['total_posts'], '</dd>

			</dl>

			<dl class="pairs pairs--justified">

				<dt>', $txt['members'], ' ', $txt['in'], ' ', $txt['total'], '</dt>

				<dd>', $context['common_stats']['total_members'], '</dd>

			</dl>

			<dl class="pairs pairs--justified">

				<dt>', $txt['latest_member'] . '</dt>

				<dd>' . $context['common_stats']['latest_member']['link'] . '</dd>

			</dl>

			<dl class="pairs pairs--justified">

				<dt>', $txt['most_online_ever'], '</dt>

				<dd>', comma_format($modSettings['mostOnline']), '</dd>

			</dl>

		</div>

	      </div>

            </div>					

                </li>           

				<li class="footerColumn footer_col3">			

				<div class="block" data-widget-id="0" data-widget-key="" data-widget-definition="online_statistics">

	<div class="block-container">

		<h3 class="block-minorHeader"><i class="fas fa-book-reader"></i>  ', $txt['online_users'], '</h3>

<div class="divider fw"></div>

		<div class="block-body block-row">

			<dl class="pairs pairs--justified">

				<dt>',$txt['guests'],'</dt>

				<dd>', comma_format($context['num_guests']), '</dd>

			</dl>



			<dl class="pairs pairs--justified">

				<dt>', $txt['user'],'</dt>

				<dd>' . comma_format($context['num_users_online']), '</dd>

			</dl>



			<dl class="pairs pairs--justified">

				<dt>' .$txt['spider'].'</dt>

				<dd>'.comma_format($context['num_spiders']) . '</dd>

			</dl>

		</div>

		<div class="block-footer">

			<a href="' . $scripturl . '?action=stats">' . $txt['more_stats'] . '</a>

		</div>

	       </div>

             </div>						

                </li>            

				<li class="footerColumn footer_col4">';

			

			if(!empty($settings['footer_blinks_state']))

				echo'			

			<div class="block">

				<div class="block-container">

				<h3 class="block-minorHeader"><i class="fas fa-envelope"></i>', empty($settings['footer_blinks_title']) ? $txt['footer_blinks_title'] : $settings['footer_blinks_title'], '</h3>

					<div class="divider fw"></div>

					<ul class="footerList">

                        ', (empty($settings['footer_blinks_1'])||empty($settings['footer_blinks_href_1'])) ? '' : '<li> <a href="'.$settings['footer_blinks_href_1'].'" target="_blank"><i class="fa fa-arrow-circle-right"></i>  '.$settings['footer_blinks_1'].'</a></li>', '

						', (empty($settings['footer_blinks_2'])||empty($settings['footer_blinks_href_2'])) ? '' : '<li> <a href="'.$settings['footer_blinks_href_2'].'" target="_blank"><i class="fa fa-phone"></i>  '.$settings['footer_blinks_2'].'</a></li>', '

						', (empty($settings['footer_blinks_3'])||empty($settings['footer_blinks_href_3'])) ? '' : '<li> <a href="'.$settings['footer_blinks_href_3'].'" target="_blank"><i class="fa fa-envelope"></i>  '.$settings['footer_blinks_3'].'</a></li>', '

						', (empty($settings['footer_blinks_4'])||empty($settings['footer_blinks_href_4'])) ? '' : '<li> <a href="'.$settings['footer_blinks_href_4'].'" target="_blank"><i class="fa fa-globe"></i>  '.$settings['footer_blinks_4'].'</a></li>', '

                      </ul>

				</div>

			</div>			

                </li>            

        </ul>

    </div>

</div>';

	}

	

	echo'

	<footer class="footer"> 

	<div class="container">

	<div class="row text-center text-sm-left flex-row-reverse"> 

	<div class="col-md-12 col-sm-12 mt-3 mt-lg-0 text-sm-left">

		', theme_copyright(), '

			<span class="text-muted d-none d-sm-inline-block float-right">

		       <i class="fas fa-heart"></i>

		        ' , $txt['wt_copyright'], '

		        </span>';



	// Show the load time?

	if ($context['show_load_time'])

		echo '

		<p>', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</p>';



	echo '

	</div>

	</div>

	</div>

	</footer>

</div>

<a href="#top" id="back-to-top" style="display: none;"><i class="fa fa-angle-up"></i></a>';

}



function template_html_below()

{

	global $context, $settings, $options, $scripturl, $txt, $modSettings;



	echo '

</body></html>';

}



// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..

function theme_linktree($force_show = false)

{

	global $context, $settings, $options, $shown_linktree;



	// If linktree is empty, just return - also allow an override.

	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))

		return;



	echo '

	<div class="page-header">

		<ol class="breadcrumb">

		<li class="breadcrumb-item">

				<a href="', $scripturl, '"><span class="fa fa-home"></span></a>

			</li>';



	// Each tree item has a URL and name. Some may have extra_before and extra_after.

	foreach ($context['linktree'] as $link_num => $tree)

	{

		echo '

			<li class="breadcrumb-item active" aria-current="page"', ($link_num == count($context['linktree']) - 1) ? ' ' : '', '>';



		// Show the link, including a URL if it should have one.

		echo $settings['linktree_link'] && isset($tree['url']) ? '

				<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] . '</span>';



		echo '

			</li>';

	}

	echo '

		</ol>

	</div>';



	$shown_linktree = true;

}



// Show the menu up top. Something like [home] [help] [profile] [logout]...

function template_menu()

{

	global $context, $settings, $options, $scripturl, $txt;



	echo '

                        

                        <ul class="nav">';



	foreach ($context['menu_buttons'] as $act => $button)

	{

		echo '

				<li id="button_', $act, '" class="nav-item with-sub">

					<a class="', $button['active_button'] ? 'active ' : '', 'nav-link firstlevel" href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '"' : '', '>

						<i class="fa fa-', $act, ' fa-lg"></i><span class="', isset($button['is_last']) ? 'last ' : '', 'firstlevel">', $button['title'], '</span>

					</a>';

		if (!empty($button['sub_buttons']))

		{

			echo '

					<div class="sub-item"><ul>';



			foreach ($button['sub_buttons'] as $childbutton)

			{

				echo '

						<li>

							<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '"' : '', '>

								<span', isset($childbutton['is_last']) ? ' class="last"' : '', '>', $childbutton['title'], !empty($childbutton['sub_buttons']) ? '...' : '', '</span>

							</a>';

				if (!empty($childbutton['sub_buttons']))

				{

					echo '

							<div class="sub-item"><ul>';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)

						echo '

								<li>

									<a href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '"' : '', '>

										<span', isset($grandchildbutton['is_last']) ? ' class="last"' : '', '>', $grandchildbutton['title'], '</span>

									</a>

								</li>';



					echo '

							</ul></div>';

				}



				echo '

						</li>';

			}

				echo '

					</ul></div>';

		}

		echo '

				</li>';

	}



	echo '

			</ul>';

}



// Generate a strip of buttons.

function template_button_strip($button_strip, $direction = 'top', $strip_options = array())

{

	global $settings, $context, $txt, $scripturl;



	if (!is_array($strip_options))

		$strip_options = array();



	// List the buttons in reverse order for RTL languages.

	if ($context['right_to_left'])

		$button_strip = array_reverse($button_strip, true);



	// Create the buttons...

	$buttons = array();

	foreach ($button_strip as $key => $value)

	{

		if (!isset($value['test']) || !empty($context[$value['test']]))

			$buttons[] = '

				<li><a' . (isset($value['id']) ? ' id="button_strip_' . $value['id'] . '"' : '') . ' class="button_strip_' . $key . (isset($value['active']) ? ' active' : '') . '" href="' . $value['url'] . '"' . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '><i class="fa fa-'.$value['text'].' fa-fw"></i> <span class="d-none d-sm-block float-right">' . $txt[$value['text']] . '</span></a></li>';

	}



	// No buttons? No button strip either.

	if (empty($buttons))

		return;



	// Make the last one, as easy as possible.

	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);



	echo '

		<div class="buttonlist', !empty($direction) ? ' float' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"': ''), '>

			<ul class="nav nav-pills">',

				implode('', $buttons), '

			</ul>

		</div>';

}



?>